<?xml version="1.0" encoding="utf-8" ?>
<xsl:stylesheet 
version="2.0" 
xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
xmlns="http://www.w3.org/1999/xhtml"
xmlns:xml="http://www.w3.org/XML/1998/namespace"
xmlns:dc="http://purl.org/dc/elements/1.1/" 
xmlns:dcx="http://purl.org/dc/terms/"
xmlns:xsd="http://www.w3.org/2001/XMLSchema#"
xmlns:ctag="http://commontag.org/ns#"
xmlns:foaf="http://xmlns.com/foaf/0.1/"
xmlns:og="http://ogp.me/ns#"
xpath-default-namespace="http://www.w3.org/1999/xhtml"> 

<xsl:import href="param.xsl"/>

<xsl:output 
method="xhtml" 
doctype-system="about:legacy-compact"
indent="yes"
encoding="utf-8"/>
<!-- ========================== Paramètres =========================== -->
<xsl:param name="id_file">unknown</xsl:param>
<xsl:param name="mode">normal</xsl:param>
<!-- ========================== Variables =========================== -->
<xsl:variable name="sommaire" select="//*[@role = 'heading']"/>
<xsl:variable name="section" select="//*[attribute::id]"/>
<xsl:variable name="content" select="//*[@class='content']"/>
<xsl:variable name="copyright" select="/html/head/meta[@name='copyright']/@content"/>
<xsl:variable name="lang" select="/html/@xml:lang"/>
<xsl:variable name="tags.nb" select="count(//*[attribute::data-tag])"/>
<!-- ========================== Règles =========================== -->

<!-- ========================== Template principal =========================== -->

<xsl:template match="html">
<!-- <xsl:text disable-output-escaping='yes'>&lt;!DOCTYPE html></xsl:text> -->
<html
xml:lang="fr" 
role="document" 
class="article">

<xsl:apply-templates select="head"/>
<xsl:apply-templates select="body"/>
</html>
</xsl:template>

<xsl:template match="/">
<xsl:apply-templates/>
</xsl:template>

<!-- ========================== Templates =========================== -->
<xsl:template match="head">
<head>
<xsl:apply-templates select="meta[@http-equiv]"/>
<xsl:if test="$mode = 'test'">
<xsl:message>====== Mode : test</xsl:message>
<base href="{$base}"/>
</xsl:if>
<xsl:copy-of select="meta[@charset]"/>
<xsl:copy-of select="meta[@name = 'language']"/>
<meta name="viewport" content="width=device-width, initial-scale=1.0"/>
<xsl:comment>CSS</xsl:comment>
<xsl:copy-of select="link[@rel = 'stylesheet']"/>
<xsl:copy-of select="script"/>
<xsl:comment>infos</xsl:comment>
<title><xsl:value-of select="link[@rel = 'up']/@title"/> | <xsl:value-of select="meta[@name = 'subject']/@content"/></title>
<!-- <xsl:copy-of select="title"/> -->
<xsl:copy-of select="meta[@name = 'subject']"/>
<xsl:copy-of select="meta[@name = 'description']"/>
<xsl:comment>RDF</xsl:comment>
<xsl:copy-of select="link[@rel = 'meta']"/>
<xsl:comment>classification</xsl:comment>
<xsl:copy-of select="meta[@name = 'classification']"/>
<xsl:comment>rating</xsl:comment>
<xsl:copy-of select="meta[@name = 'rating']"/>
<xsl:comment>tags</xsl:comment>
<xsl:copy-of select="meta[@name = 'keywords']"/>

<!-- lighbox
<xsl:comment>lighbox</xsl:comment>
<link rel="stylesheet" type="text/css" href="http://www.christopher.compagnon.name/lightbox/css/lightbox.css"  media="screen"/>
<script type="text/javascript" src="http://www.christopher.compagnon.name/lightbox/js/prototype.js"></script>
<script type="text/javascript" src="http://www.christopher.compagnon.name/lightbox/js/scriptaculous.js?load=effects,builder"></script>
<script type="text/javascript" src="http://www.christopher.compagnon.name/lightbox/js/lightbox.js"></script>
 -->
 
<!-- Gremlins
<script type="text/javascript" src="./js/gremlins.min.js"></script>
<script type="text/javascript">gremlins.createHorde().unleash();</script>
 -->

<xsl:if test="$opengraph = 'yes'"><!-- OpenGraph -->
<xsl:comment>OpenGraph</xsl:comment>
<meta property="og:type" content="article"/>
<meta property="og:title"><xsl:attribute name="content"><xsl:value-of select="title"/></xsl:attribute></meta>
<meta property="og:url"><xsl:attribute name="content"><xsl:value-of select="$base"/><xsl:value-of select="$id_file"/>.html</xsl:attribute></meta>
<meta property="og:image"><xsl:attribute name="content"><xsl:value-of select="//figure[@id='thumbnail']/img/@src"/></xsl:attribute></meta>
</xsl:if>


<xsl:if test="$dublincore = 'yes'"><!-- Dublin Core -->
<xsl:comment>Dublin Core</xsl:comment>
<meta property="dc:title"><xsl:attribute name="content"><xsl:value-of select="title"/></xsl:attribute></meta>
<meta property="dc:subject"><xsl:attribute name="content"><xsl:value-of select="meta[@name='subject']/@content"/></xsl:attribute></meta>
<meta property="dc:description"><xsl:attribute name="content"><xsl:value-of select="meta[@name='description']/@content"/></xsl:attribute></meta>
<meta property="dc:date"><xsl:attribute name="content"><xsl:value-of select="format-date(current-date(),'[Y0001]-[M01]-[D01]')"/></xsl:attribute></meta>
<meta property="dc:format"><xsl:attribute name="content">application/xhtml+xml</xsl:attribute></meta>
<meta property="dc:type"><xsl:attribute name="content">Text</xsl:attribute></meta>
<meta property="dc:language"><xsl:attribute name="content"><xsl:value-of select="$lang"/></xsl:attribute></meta>
<meta property="dc:creator"><xsl:attribute name="content"><xsl:value-of select="meta[@rel='dc:creator']/@content"/></xsl:attribute></meta>
<meta property="dc:contributor"><xsl:attribute name="content"><xsl:value-of select="meta[@rel='dc:contributor']/@content"/></xsl:attribute></meta>
<meta property="dc:publisher"><xsl:attribute name="content"><xsl:value-of select="meta[@rel='dc:publisher']/@content"/></xsl:attribute></meta>
<meta property="dc:rights"><xsl:attribute name="content"><xsl:value-of select="meta[@rel='dc:rights']/@content"/></xsl:attribute></meta>
<meta property="dc:identifier"><xsl:attribute name="content"><xsl:value-of select="$base"/><xsl:value-of select="$id_file"/>.html</xsl:attribute></meta>
<meta property="dcx:license"><xsl:attribute name="content">http://creativecommons.org/licenses/<xsl:value-of select="$copyright"/>/4.0/</xsl:attribute></meta>
<meta property="dcx:abstract"><xsl:attribute name="content"></xsl:attribute></meta>
</xsl:if>

<xsl:comment>navigation</xsl:comment>
<xsl:copy-of select="link[@rel = 'contents']"/>
<xsl:copy-of select="link[@rel = 'home']"/>
<xsl:copy-of select="link[@rel = 'up']"/>
<xsl:copy-of select="link[@rel = 'previous']"/>
<xsl:copy-of select="link[@rel = 'next']"/>
</head>


<body>
<header>
<nav>
<xsl:apply-templates select="link[@rel = 'home']"/>
<xsl:if test="$tags.nb &gt; 0"><a href="tags.html" title="Tous les tags"><img src="../commons/image/png/Tags_font_awesome.svg.png"/><p>Tous les tags</p></a></xsl:if>
<xsl:apply-templates select="link[@rel = 'up']"/>
<xsl:apply-templates select="link[@rel = 'previous']"/>
<a href="comments.sh" title="déposer un commentaire"><img src="../commons/image/png/200px-High-contrast-help-faq.svg.png"/><p>Commentaires</p></a>
<a href="contacts.html" title="envoyer un message à l'administrateur"><img src="../commons/image/png/200px-High-contrast-emblem-mail.svg.png"/><p>Contact</p></a>
<a href="site.param.sh" title="paramétrage du site"><img src="../commons/image/png/200px-High-contrast-emblem-system.svg.png"/><p>Paramètres</p></a>
<xsl:if test="$searchmodule = 'yes'"><a href="#" title="Rechercher sur le site" onclick="searchfocus()"><img src="../commons/image/png/200px-High-contrast-system-search.svg.png" /><p>Rechercher</p></a></xsl:if>
<xsl:apply-templates select="link[@rel = 'next']"/>
</nav>

<details class="navigation">
<summary>Navigation</summary>
<nav>
<a><xsl:attribute name="href"><xsl:value-of select="link[@rel = 'up']/@href"/></xsl:attribute><xsl:value-of select="link[@rel = 'up']/@title"/></a>
</nav>
</details>
</header>

<div class="articles">
<article role="article" id="{$id_file}">
	
<header>
<hgroup>
<h1><xsl:value-of select="meta[@name = 'subject']/@content"/></h1>
<p><xsl:value-of select="meta[@name = 'description']/@content"/></p>
</hgroup>

<details class="sommaire">
<summary>Sommaire</summary>
<xsl:for-each select="$section/*[@role = 'heading']">
<xsl:variable name="test" select="../@id"/>
<xsl:variable name="h" select="name(.)"/>
<xsl:element name="{$h}"><a href="#{$test}"><xsl:value-of select="."/></a></xsl:element>
</xsl:for-each>
</details>
</header>

<xsl:copy-of select="$content"/>

</article>
</div>

<footer role="contentinfo">
<section class="info-article">
<p>Ce serveur fonctionne à l'énergie renouvelable</p>
<p>
<xsl:apply-templates select="//meta[@rel='dc:creator']"/>
<xsl:apply-templates select="//meta[@rel='dc:contributor']"/>
<xsl:apply-templates select="//meta[@rel='dc:publisher']"/>
</p>
<p><a rel="meta" type="application/rdf+xml" title="Description" href="./rdf/{$id_file}.rdf" target="_blank">Informations complémentaires</a></p>
</section>

<section class="info-generale">
<p>
<xsl:call-template name="license"><xsl:with-param name="license" select="$copyright"/></xsl:call-template></p>
</section>

<xsl:if test="$searchmodule = 'yes'">
<section>
<form method="get" accept-charset="UTF-8" action="http://www.firenode.net:8090/yacysearch.html">
  <div style="text-align:center; padding:5px; background-color:#eeeeee; border:1px solid #cccccc; -webkit-border-radius:5px; -moz-border-radius:5px; border-radius:5px; display:block; float:left; margin-right:5px;">
   <!-- <div style="font-family:Arial,Helvetica,sans-serif; font-size:16px; display:block; float:left; padding-top:3px; padding-right:5px;">
      MySearch
    </div>-->
    <input type="text" id="yquery" name="query" value="" maxlength="80" 
           style="width:300px; font-size:16px; float:left;"/>
    <input type="hidden" name="verify" value="cacheonly"/>
    <input type="hidden" name="maximumRecords" value="10"/>
    <input type="hidden" name="meanCount" value="5" />
    <input type="hidden" name="resource" value="local"/>
    <input type="hidden" name="urlmaskfilter" value=".*" />
    <input type="hidden" name="prefermaskfilter" value="firenode.net"/>
    <input type="hidden" name="display" value="2" />
    <input type="hidden" name="nav" value="all" />
    <div style="font-size:16px; display:block; float:right; padding-top:1px;">
      <input type="submit" name="Enter" value="Rechercher" role="button"/>
    </div>
  </div>
  <p style="clear:both;"><a href="http://www.firenode.net:8090/" title="Recherche avancée" target="_blank">Recherche avancée</a></p>
</form>
</section>
</xsl:if>
</footer>

<!-- instantclick -->
<xsl:comment>instantclick</xsl:comment>
<script type="text/javascript" src="./js/instantclick.min.js" data-no-instant="data-no-instant"></script>
<script data-no-instant="data-no-instant">InstantClick.init();</script>
</body>
</xsl:template>

<xsl:template match="body">
</xsl:template>

<xsl:template match="link[@rel = 'home']">
<a href="{@href}" title="{@title}" accesskey="1"><img src="../commons/image/png/200px-Home_Icon.svg.png"/><p>Index</p></a>	
</xsl:template>

<xsl:template match="link[@rel = 'up']">
<a href="{@href}" title="{@title}"  accesskey="5"><img src="../commons/image/png/200px-High-contrast-go-up.svg.png"/><p>Retour</p></a>	
</xsl:template>

<xsl:template match="link[@rel = 'previous']">
<a href="{@href}" title="{@title}"><img src="../commons/image/png/200px-High-contrast-go-previous.svg.png"/><p>Précédent</p></a>	
</xsl:template>

<xsl:template match="link[@rel = 'next']">
<a href="{@href}" title="{@title}"><img src="../commons/image/png/200px-High-contrast-go-next.svg.png"/><p>Suivant</p></a>	
</xsl:template>

<xsl:template match="div[@class = 'content']" mode="article"><xsl:copy-of select="."/></xsl:template>

<xsl:template name="license">
<xsl:param name="license"/>
<!-- <img alt="Creative Commons License" src="http://i.creativecommons.org/l/{$license}/4.0/88x31.png"/> -->
<a rel="license external" href="http://creativecommons.org/licenses/{$license}/4.0/" target="_blank">
<img alt="Licence Creative Commons" src="http://i.creativecommons.org/l/{$license}/4.0/80x15.png"/>
</a>
</xsl:template>

<xsl:template match="//meta[@rel='dc:creator']">
<xsl:variable name="author.content" select="./@content"/>
<xsl:variable name="author.href" select="./@resource"/>
Auteur : <a rel="meta" type="application/rdf+xml" title="Profile (foaf)" href="{$author.href}" target="_blank"><xsl:value-of select="$author.content"/></a>
</xsl:template>

<xsl:template match="//meta[@rel='dc:contributor']">
<xsl:variable name="contributor.content" select="./@content"/>
<xsl:variable name="contributor.href" select="./@resource"/>
  &#x25C6; Contributeur : <a rel="meta" type="application/rdf+xml" title="Profile (foaf)" href="{$contributor.href}" target="_blank"><xsl:value-of select="$contributor.content"/></a>
</xsl:template>

<xsl:template match="//meta[@rel='dc:publisher']">
<xsl:variable name="publisher.content" select="./@content"/>
<xsl:variable name="publisher.href" select="./@resource"/>
  &#x25C6; Publication : <a rel="meta" type="application/rdf+xml" title="Profile (foaf)" href="{$publisher.href}" target="_blank"><xsl:value-of select="$publisher.content"/></a>
</xsl:template>
<!-- ========================== actions par défaut =========================== -->
<xsl:template match="text()"/>
<xsl:template match="text()" mode="article"/>
</xsl:stylesheet>
